@@ -1,5 +1,5 @@
 /*
- * $Id: thwinp.h,v 1.3 2001/05/18 04:51:02 thep Exp $
+ * $Id: thwinp.h,v 1.4 2001/09/17 01:53:02 thep Exp $
  * thwinp.h - Thai wide-char string input sequence filtering
  * Created: 2001-05-17
  */
@@ -12,7 +12,7 @@
 
 BEGIN_CDECL
 
-extern int th_wciscompose(thwchar_t c1, thwchar_t c2, thstrict_t s);
+extern int th_wcisaccept(thwchar_t c1, thwchar_t c2, thstrict_t s);
 extern int th_wcvalidate(thwchar_t *c1, thwchar_t *c2, thstrict_t s);
 
 END_CDECL
