@@ -1,7 +1,8 @@
 /*
- * $Id: thstr.c,v 1.2 2001/08/14 06:11:42 thep Exp $
+ * $Id: thstr.c,v 1.4 2004/10/13 06:41:17 thep Exp $
  * thstr.c - Thai string manipulators
  * Created: 2001-08-03
+ * Author:  Theppitak Karoonboonyanan <thep@links.nectec.or.th>
  */
 
 #include <thai/thstr.h>
@@ -30,9 +31,13 @@ size_t th_normalize(thchar_t dest[], const thchar_t *src, size_t n)
         case -1 : 
             low = *src; break;
         case 1 : 
+            if (up && th_chlevel (up) == 3) { top = up; }
             up = *src; break;
         case 2 : 
             top = *src; break;
+        case 3 : 
+            if (!up) { up = *src; }
+            else { top = *src; }
         }
         ++src;
     }
